@@ -8,13 +8,13 @@ class DefaultView(BaseView):
     def __init__(self, name: str, resources: Sequence, title: str = "", description: str = "", attribution: str = "",
                  spec_type: str = "simple", spec: dict = None, type: str = "", group: str = "",
                  series: Sequence = list(), row_limit: int = 500, metadata: dict = None):
-        super().__init__(name=name, resources=resources, description=description, attribution=attribution,
+        super().__init__(name=name, resources=resources, title=title, description=description, attribution=attribution,
                          spec_type=spec_type, spec=spec, type=type, group=group,
                          series=series, row_limit=row_limit, metadata=metadata)
 
     def add_to_datapackage(self, dp):
         dp.datapackage_metadata["views"].append({
-            'name': file_functions.url_encode(self._name),
+            'name': file_functions.format_filename(self._name),
             'title': self._title,
             'description': self._description,
             'attribution': self._attribution,
